hyperbole
Safe HaskellNone
LanguageGHC2021

Web.Hyperbole.Effect.Hyperbole

Synopsis

Documentation

data Hyperbole (a :: Type -> Type) b where Source #

The Hyperbole Effect allows you to access information in the Request, manually respond, and manipulate the Client session and query.

Constructors

GetRequest :: forall (a :: Type -> Type). Hyperbole a Request 
RespondNow :: forall (a :: Type -> Type) b. Response -> Hyperbole a b 
PushUpdate :: forall (a :: Type -> Type). ViewUpdate -> Hyperbole a () 
ModClient :: forall (a :: Type -> Type). (Client -> Client) -> Hyperbole a () 
GetClient :: forall (a :: Type -> Type). Hyperbole a Client 
PushTrigger :: forall (a :: Type -> Type). TargetViewId -> Encoded -> Hyperbole a () 
PushEvent :: forall (a :: Type -> Type). Text -> Value -> Hyperbole a () 

Instances

Instances details
type DispatchOf Hyperbole Source # 
Instance details

Defined in Web.Hyperbole.Effect.Hyperbole

runHyperboleLocal :: forall (es :: [(Type -> Type) -> Type -> Type]). Request -> Eff (Error Response ': (State Client ': (Writer [Remote] ': es))) Response -> Eff es (Response, Client, [Remote]) Source #

request :: forall (es :: [Effect]). Hyperbole :> es => Eff es Request Source #

Return all information about the Request