| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Web.Hyperbole.Effect.Hyperbole
Synopsis
- data Hyperbole (a :: Type -> Type) b where
- GetRequest :: forall (a :: Type -> Type). Hyperbole a Request
- RespondNow :: forall (a :: Type -> Type) b. Response -> Hyperbole a b
- PushUpdate :: forall (a :: Type -> Type). ViewUpdate -> Hyperbole a ()
- ModClient :: forall (a :: Type -> Type). (Client -> Client) -> Hyperbole a ()
- GetClient :: forall (a :: Type -> Type). Hyperbole a Client
- PushTrigger :: forall (a :: Type -> Type). TargetViewId -> Encoded -> Hyperbole a ()
- PushEvent :: forall (a :: Type -> Type). Text -> Value -> Hyperbole a ()
- data Remote
- runHyperboleLocal :: forall (es :: [(Type -> Type) -> Type -> Type]). Request -> Eff (Error Response ': (State Client ': (Writer [Remote] ': es))) Response -> Eff es (Response, Client, [Remote])
- request :: forall (es :: [Effect]). Hyperbole :> es => Eff es Request
Documentation
data Hyperbole (a :: Type -> Type) b where Source #
The Hyperbole Effect allows you to access information in the Request, manually respond, and manipulate the Client session and query.
Constructors
| GetRequest :: forall (a :: Type -> Type). Hyperbole a Request | |
| RespondNow :: forall (a :: Type -> Type) b. Response -> Hyperbole a b | |
| PushUpdate :: forall (a :: Type -> Type). ViewUpdate -> Hyperbole a () | |
| ModClient :: forall (a :: Type -> Type). (Client -> Client) -> Hyperbole a () | |
| GetClient :: forall (a :: Type -> Type). Hyperbole a Client | |
| PushTrigger :: forall (a :: Type -> Type). TargetViewId -> Encoded -> Hyperbole a () | |
| PushEvent :: forall (a :: Type -> Type). Text -> Value -> Hyperbole a () |
Instances
| type DispatchOf Hyperbole Source # | |
Defined in Web.Hyperbole.Effect.Hyperbole | |
Constructors
| RemoteAction TargetViewId Encoded | |
| RemoteEvent Text Value |